@@ -1,11 +1,17 @@
 import logging
 import os.path
+import random
+import string
+import time
+import uuid
 from functools import reduce
 from itertools import groupby
 from typing import List, Dict, Union
 import inspect
 from importlib.util import spec_from_file_location, module_from_spec
 
+from lesscode_utils.encryption_algorithm import MD5
+
 
 def list_dict_group(data: List[Dict], key):
     """
@@ -149,3 +155,42 @@ def get_members_from_file(file_path: str, name="module"):
         return members_list
     else:
         raise Exception(f"file_path={file_path} not exist")
+
+
+def short_str(value: str, n: int = 1, flag=True, chars=string.ascii_letters + string.digits):
+    key = f"{int(time.time() * 1000)}{uuid.uuid4().hex}"
+    new_value = f"{key}{value}" if flag else value
+    md_str = MD5.encrypt(new_value)
+    result = []
+    for i in range(0, len(md_str), 8):
+        lh = 0x3FFFFFFF & int(md_str[i:i + 8], 16)
+        out_chars = ""
+        for j in range(0, n):
+            index = lh & 0x0000003D
+            out_chars += chars[index]
+            lh >>= 5
+        result.append(random.choice(out_chars))
+    return "".join(result)
+
+
+def get_short_id(chars=string.ascii_letters + string.digits):
+    _id = uuid.uuid4().hex
+    buffer = []
+    for i in range(0, 8):
+        start = i * 4
+        end = i * 4 + 4
+        val = int(_id[start:end], 32)
+        buffer.append(chars[val % 62])
+    return "".join(buffer)
+
+
+def str2short_str(value: str, n: int = 5, chars=string.ascii_letters + string.digits):
+    uuid_obj = uuid.uuid5(uuid.NAMESPACE_DNS, value)
+    uuid_int = uuid_obj.int
+    short_str = ""
+    for _ in range(n):
+        idx = uuid_int % len(chars)
+        short_str += chars[idx]
+        uuid_int //= len(chars)
+
+    return short_str
